@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.11 2001/02/01 10:34:51 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.12 2001/05/17 18:58:20 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -99,12 +99,15 @@ static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 	if (td->keyword_given==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR; 
 	
 	memmove(td->keyword_given, key, lenofkey);
-	td->akey = mxcalloc(1, mcrypt_get_size(td));
+	i = mcrypt_get_size(td);
+	td->akey = mxcalloc(1, i);
 	if (td->akey==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR;
 
-	td->abuf = mxcalloc(1, mcrypt_mode_get_size(td));
-	if (td->abuf==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR;
-
+	i = mcrypt_mode_get_size(td);
+	if (i > 0) {
+		td->abuf = mxcalloc(1, i);
+		if (td->abuf==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR;
+	}
 	init_mcrypt(td, td->abuf, key, key_size, IV);
 
 	ok = mcrypt_set_key(td,
@@ -130,7 +133,7 @@ static int internal_end_mcrypt(MCRYPT td)
 	td->akey = NULL;
 
 	end_mcrypt(td, td->abuf);
-	mxfree(td->abuf, mcrypt_mode_get_size(td));
+	if (td->abuf!=NULL) mxfree(td->abuf, mcrypt_mode_get_size(td));
 	td->abuf = NULL;
 
 	return 0;
