@@ -25,8 +25,8 @@
 #include <mcrypt_internal.h>
 #include <xmemory.h>
 
-#if 0
-extern int preloaded_symbols;
+#ifndef DEBUG
+# define fputs(x, y) 1
 #endif
 
 WIN32DLL_DEFINE
@@ -35,7 +35,9 @@ int mcrypt_module_close(MCRYPT td)
 
 	lt_dlclose(td->algorithm_handle);
 	lt_dlclose(td->mode_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	td->algorithm_handle = NULL;
 	td->mode_handle = NULL;
@@ -142,8 +144,6 @@ MCRYPT mcrypt_module_open(char *algorithm,
 		return MCRYPT_FAILED;
 	}
 
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
-
 	td->algorithm_handle = mcrypt_dlopen(a_directory, m_directory, algorithm);
 	if (td->algorithm_handle == NULL) {
 		err=lt_dlerror();
@@ -187,11 +187,10 @@ int mcrypt_get_size(MCRYPT td)
 	int (*_mcrypt_get_size) (void);
 
 	const char *error;
-	char *s;
 
-	s = td->algorithm_handle;
-	_mcrypt_get_size = lt_dlsym(s, "_mcrypt_get_size");
-	if ((error = lt_dlerror())) {
+	_mcrypt_get_size = lt_dlsym(td->algorithm_handle, "_mcrypt_get_size");
+	if (_mcrypt_get_size == NULL) {
+		error = lt_dlerror();
 		if (error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
@@ -205,11 +204,10 @@ int mcrypt_mode_get_size(MCRYPT td)
 	int (*_mcrypt_get_size) (void);
 
 	const char *error;
-	char *s;
 
-	s = td->mode_handle;
-	_mcrypt_get_size = lt_dlsym(s, "_mcrypt_mode_get_size");
-	if ((error = lt_dlerror())) {
+	_mcrypt_get_size = lt_dlsym(td->mode_handle, "_mcrypt_mode_get_size");
+	if (_mcrypt_get_size == NULL) {
+		error = lt_dlerror();
 		if (error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
@@ -223,21 +221,21 @@ int mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 	int (*__mcrypt_set_key_stream) (void *, void *, int, void *, int);
 	int (*__mcrypt_set_key_block) (void *, void *, int);
 	const char *error;
-	char *s;
 
-	s = td->algorithm_handle;
 	if (mcrypt_enc_is_block_algorithm(td) == 0) {
 		/* stream */
-		__mcrypt_set_key_stream = lt_dlsym(s, "_mcrypt_set_key");
-		if ((error = lt_dlerror())) {
+		__mcrypt_set_key_stream = lt_dlsym(td->algorithm_handle, "_mcrypt_set_key");
+		if (__mcrypt_set_key_stream == NULL) {
+			error = lt_dlerror();
 			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
 			return -2;
 		}
 		return __mcrypt_set_key_stream(a, b, c, d, e);
 	} else {
-		__mcrypt_set_key_block = lt_dlsym(s, "_mcrypt_set_key");
-		if ((error = lt_dlerror())) {
+		__mcrypt_set_key_block = lt_dlsym(td->algorithm_handle, "_mcrypt_set_key");
+		if (__mcrypt_set_key_block == NULL) {
+		 	error = lt_dlerror();
 			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
 			return -2;
@@ -251,12 +249,10 @@ int mcrypt_enc_set_state(MCRYPT td, void *iv, int size)
 {
 	int (*__mcrypt_set_state) (void *, void *, int);
 	const char *error;
-	char *s;
 
-	s = td->mode_handle;
-
-	__mcrypt_set_state = lt_dlsym(s, "_mcrypt_set_state");
-	if ((error = lt_dlerror())) {
+	__mcrypt_set_state = lt_dlsym(td->mode_handle, "_mcrypt_set_state");
+	if (__mcrypt_set_state==NULL) {
+		error = lt_dlerror();
 		if (error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
@@ -277,11 +273,8 @@ WIN32DLL_DEFINE
 int mcrypt_get_algo_iv_size(MCRYPT td)
 {
 	int (*_mcrypt_get_algo_iv_size) (void);
-	char *s;
 
-	s = td->algorithm_handle;
-
-	_mcrypt_get_algo_iv_size = lt_dlsym(s, "_mcrypt_get_algo_iv_size");
+	_mcrypt_get_algo_iv_size = lt_dlsym(td->algorithm_handle, "_mcrypt_get_algo_iv_size");
 	return _mcrypt_get_algo_iv_size();
 }
 
@@ -299,11 +292,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_get_key_size(MCRYPT td)
 {
 	int (*_mcrypt_get_key_size) (void);
-	char *s;
 
-	s = td->algorithm_handle;
-
-	_mcrypt_get_key_size = lt_dlsym(s, "_mcrypt_get_key_size");
+	_mcrypt_get_key_size = lt_dlsym(td->algorithm_handle, "_mcrypt_get_key_size");
 	return _mcrypt_get_key_size();
 }
 
@@ -311,13 +301,10 @@ WIN32DLL_DEFINE
 int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len)
 {
 	int *(*_mcrypt_get_key_sizes) (int *);
-	char *s;
 	int *size;
 
-	s = td->algorithm_handle;
-
 	_mcrypt_get_key_sizes =
-	    lt_dlsym(s, "_mcrypt_get_supported_key_sizes");
+	    lt_dlsym(td->algorithm_handle, "_mcrypt_get_supported_key_sizes");
 	size = _mcrypt_get_key_sizes(len);
 
 	return size;
@@ -327,11 +314,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_is_block_algorithm(MCRYPT td)
 {
 	int (*_is_block_algorithm) (void);
-	char *s;
 
-	s = td->algorithm_handle;
-
-	_is_block_algorithm = lt_dlsym(s, "_is_block_algorithm");
+	_is_block_algorithm = lt_dlsym(td->algorithm_handle, "_is_block_algorithm");
 	return _is_block_algorithm();
 }
 
@@ -339,12 +323,9 @@ WIN32DLL_DEFINE
 char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 {
 	char *(*_mcrypt_get_algorithms_name) (void);
-	char *s;
-
-	s = td->algorithm_handle;
 
 	_mcrypt_get_algorithms_name =
-	    lt_dlsym(s, "_mcrypt_get_algorithms_name");
+	    lt_dlsym(td->algorithm_handle, "_mcrypt_get_algorithms_name");
 	return _mcrypt_get_algorithms_name();
 }
 
@@ -352,10 +333,8 @@ WIN32DLL_DEFINE
 int init_mcrypt(MCRYPT td, void *buf, void *a, int b, void *c)
 {
 	int (*_init_mcrypt) (void *, void *, int, void *, int);
-	char *s;
 
-	s = td->mode_handle;
-	_init_mcrypt = lt_dlsym(s, "_init_mcrypt");
+	_init_mcrypt = lt_dlsym(td->mode_handle, "_init_mcrypt");
 	return _init_mcrypt(buf, a, b, c, mcrypt_enc_get_block_size(td));
 }
 
@@ -363,10 +342,8 @@ WIN32DLL_DEFINE
 int end_mcrypt(MCRYPT td, void *buf)
 {
 	int (*_end_mcrypt) (void *);
-	char *s;
 
-	s = td->mode_handle;
-	_end_mcrypt = lt_dlsym(s, "_end_mcrypt");
+	_end_mcrypt = lt_dlsym(td->mode_handle, "_end_mcrypt");
 	return _end_mcrypt(buf);
 }
 
@@ -394,11 +371,8 @@ WIN32DLL_DEFINE
 char *mcrypt_enc_get_modes_name(MCRYPT td)
 {
 	char *(*_mcrypt_get_modes_name) (void);
-	char *s;
 
-	s = td->mode_handle;
-
-	_mcrypt_get_modes_name = lt_dlsym(s, "_mcrypt_get_modes_name");
+	_mcrypt_get_modes_name = lt_dlsym(td->mode_handle, "_mcrypt_get_modes_name");
 	return _mcrypt_get_modes_name();
 }
 
@@ -406,11 +380,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_is_block_mode(MCRYPT td)
 {
 	int (*_is_block_mode) (void);
-	char *s;
 
-	s = td->mode_handle;
-
-	_is_block_mode = lt_dlsym(s, "_is_block_mode");
+	_is_block_mode = lt_dlsym(td->mode_handle, "_is_block_mode");
 	return _is_block_mode();
 }
 
@@ -418,11 +389,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_mode_has_iv(MCRYPT td)
 {
 	int (*_has_iv) (void);
-	char *s;
 
-	s = td->mode_handle;
-
-	_has_iv = lt_dlsym(s, "_has_iv");
+	_has_iv = lt_dlsym(td->mode_handle, "_has_iv");
 	return _has_iv();
 }
 
@@ -430,11 +398,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_is_block_algorithm_mode(MCRYPT td)
 {
 	int (*_is_a_block_mode) (void);
-	char *s;
 
-	s = td->mode_handle;
-
-	_is_a_block_mode = lt_dlsym(s, "_is_block_algorithm_mode");
+	_is_a_block_mode = lt_dlsym(td->mode_handle, "_is_block_algorithm_mode");
 	return _is_a_block_mode();
 }
 
@@ -442,11 +407,8 @@ WIN32DLL_DEFINE
 int mcrypt_enc_self_test(MCRYPT td)
 {
 	int (*_self_test) (void);
-	char *s;
 
-	s = td->algorithm_handle;
-
-	_self_test = lt_dlsym(s, "_mcrypt_self_test");
+	_self_test = lt_dlsym(td->algorithm_handle, "_mcrypt_self_test");
 
 	return _self_test();
 }
@@ -455,15 +417,13 @@ WIN32DLL_DEFINE
 int mcrypt_module_self_test(char *algorithm, char *a_directory)
 {
 	int i;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_self_test) (void);
 	const char* error;
 
-
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 
@@ -471,6 +431,7 @@ int mcrypt_module_self_test(char *algorithm, char *a_directory)
 		error=lt_dlerror();
 		if (error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
+		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
@@ -479,7 +440,10 @@ int mcrypt_module_self_test(char *algorithm, char *a_directory)
 	i = _self_test();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
+
 	return i;
 }
 
@@ -494,7 +458,6 @@ int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
@@ -509,7 +472,9 @@ int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 	i = _version();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -518,14 +483,13 @@ WIN32DLL_DEFINE
 int mcrypt_module_mode_version(char *mode, char *m_directory)
 {
 	int i;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_version) (void);
 	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
@@ -540,7 +504,9 @@ int mcrypt_module_mode_version(char *mode, char *m_directory)
 	i = _version();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -556,7 +522,6 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	
@@ -572,7 +537,9 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 	i = _is_block_algorithm();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -581,14 +548,13 @@ WIN32DLL_DEFINE
 int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 {
 	int i;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_is_a_block_mode) (void);
 	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
@@ -603,7 +569,9 @@ int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 	i = _is_a_block_mode();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -612,14 +580,13 @@ WIN32DLL_DEFINE
 int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 {
 	int i;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_is_block_mode) (void);
 	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
@@ -634,7 +601,9 @@ int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 	i = _is_block_mode();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -650,7 +619,6 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
@@ -665,7 +633,9 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 	i = _get_block_size();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -681,7 +651,6 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
@@ -696,7 +665,9 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 	i = _get_key_size();
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return MCRYPT_UNKNOWN_ERROR;
+	}
 
 	return i;
 }
@@ -715,7 +686,6 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 		*len = 0;
 		return NULL;
 	}
-/*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
 	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
@@ -732,7 +702,9 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	size = _mcrypt_get_key_sizes(len);
 
 	lt_dlclose(_handle);
-	lt_dlexit();
+	if (lt_dlexit() != 0) {
+		return NULL;
+	}
 
 	return size;
 }
