@@ -31,6 +31,7 @@ static const char * _mcrypt_mutex_geterror (void) {
  return NULL;
 }
 
+# ifndef NO_DLMUTEX
 int mcrypt_mutex_register ( void (*mutex_lock)(void) , 
 			void (*mutex_unlock)(void)) 
 {
@@ -39,4 +40,11 @@ int mcrypt_mutex_register ( void (*mutex_lock)(void) ,
 		_mcrypt_mutex_seterror, _mcrypt_mutex_geterror);
 
 }
+# else
+int mcrypt_mutex_register ( void (*mutex_lock)(void) ,
+                        void (*mutex_unlock)(void))   
+                        {
+                        return 0;
+}
+# endif /* NO_DLMUTEX */
 #endif
