@@ -9,7 +9,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: 3-way.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
+/* $Id: 3-way.c,v 1.6 2001/05/16 17:54:24 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -34,13 +34,15 @@
 #endif
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key (word32 *k, word32* input_key, int len) {
-        k[0]=0;         k[2]=0;
-        k[1]=0;
-        memmove (k, input_key,len);
-        return 0;
+    int _mcrypt_set_key(word32 * k, word32 * input_key, int len)
+{
+	k[0] = 0;
+	k[2] = 0;
+	k[1] = 0;
+	memmove(k, input_key, len);
+	return 0;
 }
-                        
+
 
 void mu(word32 * a)
 {				/* inverts the order of the bits of a */
@@ -145,8 +147,7 @@ void rndcon_gen(word32 strt, word32 * rtab)
 	}
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt( word32 * tk, word32 * ta)
+WIN32DLL_DEFINE void _mcrypt_encrypt(word32 * tk, word32 * ta)
 {
 	int i;
 	word32 rcon[NMBR + 1];
@@ -197,8 +198,7 @@ void _mcrypt_encrypt( word32 * tk, word32 * ta)
 }
 
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(word32 * k, word32 * ta)
+WIN32DLL_DEFINE void _mcrypt_decrypt(word32 * k, word32 * ta)
 {
 	int i;
 	word32 ki[3];		/* the `inverse' key             */
@@ -252,70 +252,94 @@ void _mcrypt_decrypt(word32 * k, word32 * ta)
 
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return 3*sizeof(word32);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 12; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 12; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(1*sizeof(int));
-        size[0]=12;
-	*len=1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return 3 * sizeof(word32);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 12;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 12;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 12;
+	*len = 1;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "3-WAY");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "3-WAY"); return x;}
 
 #define CIPHER "46823287358d68f6e034ca62"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
