@@ -7,7 +7,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish-compat.c,v 1.4 2001/03/11 20:30:28 nmav Exp $ */
+/* $Id: blowfish-compat.c,v 1.5 2001/05/16 17:54:25 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -41,8 +41,7 @@ typedef struct {
 #define F(bc, x) ( ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][x & 0xff] )
 
 /* x should be a 64 bit integer */
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(blf_ctx * c, word32 * x)
+WIN32DLL_DEFINE void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 {
 	word32 Xl;
 	word32 Xr, temp;
@@ -56,7 +55,7 @@ void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 	Xr = byteswap32(x[1]);
 #endif
 
-for (i = 0; i < BF_N; ++i) {
+	for (i = 0; i < BF_N; ++i) {
 		Xl ^= c->P[i];
 		Xr ^= F(c, Xl);
 
@@ -112,8 +111,7 @@ static void enblf_noswap(blf_ctx * c, word32 * x)
 	x[1] = Xr;
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(blf_ctx * c, word32 * x)
+WIN32DLL_DEFINE void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 {
 	word32 Xl, Xr, temp;
 	short i;
@@ -535,14 +533,14 @@ static short initialize_blowfish(blf_ctx * c, byte key[], short keybytes)
 
 	j = 0;
 	for (i = 0; i < BF_N + 2; ++i) {
-                data = 0x00000000;
-                data = (data << 8) | key[(j)   % keybytes];
-                data = (data << 8) | key[(j+1) % keybytes];
-                data = (data << 8) | key[(j+2) % keybytes];
-                data = (data << 8) | key[(j+3) % keybytes];
- 
-                c->P[i] ^= data;
-                j = (j + 4) % keybytes;
+		data = 0x00000000;
+		data = (data << 8) | key[(j) % keybytes];
+		data = (data << 8) | key[(j + 1) % keybytes];
+		data = (data << 8) | key[(j + 2) % keybytes];
+		data = (data << 8) | key[(j + 3) % keybytes];
+
+		c->P[i] ^= data;
+		j = (j + 4) % keybytes;
 	}
 
 	datarl[0] = 0x000000000;
@@ -567,75 +565,97 @@ static short initialize_blowfish(blf_ctx * c, byte key[], short keybytes)
 	return 0;
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_set_key(blf_ctx * c, char *k, int len)
+WIN32DLL_DEFINE int _mcrypt_set_key(blf_ctx * c, char *k, int len)
 {
 	initialize_blowfish(c, k, len);
 	return 0;
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(blf_ctx);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 56; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	*len=0;
-        return NULL;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(blf_ctx);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 56;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	*len = 0;
+	return NULL;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "Blowfish");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Blowfish"); return x;}
 
 #define CIPHER "de8e9a3a9cd44280"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
-
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
