@@ -14,7 +14,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: des.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
+/* $Id: des.c,v 1.7 2001/05/17 19:09:08 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -36,7 +36,8 @@
 
 /* #define	NULL	0 */
 
-static void permute_ip(), permute_fp(), perminit_ip(), spinit(), perminit_fp();
+static void permute_ip(), permute_fp(), perminit_ip(), spinit(),
+perminit_fp();
 static word32 f();
 
 
@@ -193,12 +194,12 @@ static int nibblebit[] = {
 /* Allocate space and initialize DES lookup arrays
  * mode == 0: standard Data Encryption Algorithm
  */
-int _mcrypt_desinit(DES_KEY* key)
+static int _mcrypt_desinit(DES_KEY * key)
 {
 
 	spinit(key);
-	perminit_ip( key);
-	perminit_fp( key);
+	perminit_ip(key);
+	perminit_fp(key);
 
 	return 0;
 }
@@ -206,16 +207,16 @@ int _mcrypt_desinit(DES_KEY* key)
 
 /* Set key (initialize key schedule array) */
 WIN32DLL_DEFINE
-int _mcrypt_set_key(DES_KEY* dkey, char* user_key, int len)
+    int _mcrypt_set_key(DES_KEY * dkey, char *user_key, int len)
 {
 	char pc1m[56];		/* place to modify pc1 into */
 	char pcr[56];		/* place to rotate pc1 into */
 	register int i, j, l;
 	int m;
-	
-	Bzero( dkey, sizeof(DES_KEY));
+
+	Bzero(dkey, sizeof(DES_KEY));
 	_mcrypt_desinit(dkey);
-	
+
 	/* Clear key schedule */
 
 
@@ -242,12 +243,11 @@ int _mcrypt_set_key(DES_KEY* dkey, char* user_key, int len)
 			}
 		}
 	}
-return 0;
+	return 0;
 }
 
 /* In-place encryption of 64-bit block */
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(DES_KEY *key, char* block)
+WIN32DLL_DEFINE void _mcrypt_encrypt(DES_KEY * key, char *block)
 {
 	register word32 left, right;
 	register char *knp;
@@ -270,35 +270,35 @@ void _mcrypt_encrypt(DES_KEY *key, char* block)
 	knp = &key->kn[0][0];
 	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp += 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp += 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 
 	/* Left/right half swap, plus byte swap if little-endian */
 #ifndef	WORDS_BIGENDIAN
@@ -310,12 +310,12 @@ void _mcrypt_encrypt(DES_KEY *key, char* block)
 #endif
 	permute_fp((char *) work, key, block);	/* Inverse initial permutation */
 }
+
 /* In-place decryption of 64-bit block. This function is the mirror
  * image of encryption; exactly the same steps are taken, but in
  * reverse order
  */
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(DES_KEY* key, char* block)
+WIN32DLL_DEFINE void _mcrypt_decrypt(DES_KEY * key, char *block)
 {
 	register word32 left, right;
 	register char *knp;
@@ -337,37 +337,37 @@ void _mcrypt_decrypt(DES_KEY* key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[15][0];
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 	knp -= 8;
-	right ^= f( key, left, knp);
+	right ^= f(key, left, knp);
 	knp -= 8;
-	left ^= f( key, right, knp);
+	left ^= f(key, right, knp);
 
 #ifndef	WORDS_BIGENDIAN
 	work[0] = byteswap32(left);
@@ -380,7 +380,7 @@ void _mcrypt_decrypt(DES_KEY* key, char* block)
 }
 
 /* Permute inblock with perm */
-static void permute_ip(char* inblock, DES_KEY *key, char* outblock)
+static void permute_ip(char *inblock, DES_KEY * key, char *outblock)
 {
 	register char *ib, *ob;	/* ptr to input or output block */
 	register char *p, *q;
@@ -407,7 +407,7 @@ static void permute_ip(char* inblock, DES_KEY *key, char* outblock)
 }
 
 /* Permute inblock with perm */
-static void permute_fp(char* inblock, DES_KEY *key, char* outblock)
+static void permute_fp(char *inblock, DES_KEY * key, char *outblock)
 {
 	register char *ib, *ob;	/* ptr to input or output block */
 	register char *p, *q;
@@ -434,7 +434,7 @@ static void permute_fp(char* inblock, DES_KEY *key, char* outblock)
 }
 
 /* The nonlinear function f(r,k), the heart of DES */
-static word32 f(DES_KEY* key, register word32 r, register char* subkey)
+static word32 f(DES_KEY * key, register word32 r, register char *subkey)
 {
 	register word32 *spp;
 	register word32 rval, rt;
@@ -484,8 +484,9 @@ static word32 f(DES_KEY* key, register word32 r, register char* subkey)
 #endif
 	return rval;
 }
+
 /* initialize a perm array */
-static void perminit_ip(DES_KEY *key)
+static void perminit_ip(DES_KEY * key)
 {
 	register int l, j, k;
 	int i, m;
@@ -506,13 +507,13 @@ static void perminit_ip(DES_KEY *key)
 			}
 }
 
-static void perminit_fp(DES_KEY *key)
+static void perminit_fp(DES_KEY * key)
 {
 	register int l, j, k;
 	int i, m;
 
 	/* Clear the permutation array */
-	Bzero( key->fperm, 16 * 16 * 8);
+	Bzero(key->fperm, 16 * 16 * 8);
 
 	for (i = 0; i < 16; i++)	/* each input nibble position */
 		for (j = 0; j < 16; j++)	/* each possible input nibble */
@@ -528,7 +529,7 @@ static void perminit_fp(DES_KEY *key)
 }
 
 /* Initialize the lookup table for the combined S and P boxes */
-static void spinit(DES_KEY *key)
+static void spinit(DES_KEY * key)
 {
 	char pbox[32];
 	int p, i, s, j, rowcol;
@@ -563,77 +564,104 @@ static void spinit(DES_KEY *key)
 			key->sp[s][i] = val;
 
 #ifdef DEBUG
-			printf("sp[%d][%2d] = %08lx\n", s, i, key->sp[s][i]);
+			printf("sp[%d][%2d] = %08lx\n", s, i,
+			       key->sp[s][i]);
 #endif
 		}
 	}
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(DES_KEY);}
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(DES_KEY);
+}
 
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 8; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(1*sizeof(int));
-        size[0]=8;
-        *len = 1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 8;
+	*len = 1;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "DES");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "DES"); return x;}
 
 #define CIPHER "a1502d70ba1320c8"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = calloc(1, blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
