@@ -26,7 +26,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: gost.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
+/* $Id: gost.c,v 1.6 2001/05/16 17:54:25 nmav Exp $ */
 
 /*
  * If you read the standard, it belabors the point of copying corresponding
@@ -77,7 +77,7 @@ void _mcrypt_kboxinit(void);
  * used in an application for the Central Bank of the Russian Federation
  * --Nikos
  */
-static int init=0;
+static int init = 0;
 
 static unsigned char const k1[16] = {
 	1, 15, 13, 0, 5, 7, 10, 4, 9, 2, 3, 14, 6, 11, 8, 2
@@ -115,15 +115,19 @@ static unsigned char k21[256];
  * This must be called once for global setup.
  */
 
-WIN32DLL_DEFINE
-int _mcrypt_set_key (word32 *inst, word32* key, int len) {
+WIN32DLL_DEFINE int _mcrypt_set_key(word32 * inst, word32 * key, int len)
+{
 
 	_mcrypt_kboxinit();
-	inst[0] = 0;	inst[1] = 0;
-	inst[2] = 0;	inst[3] = 0;
-	inst[4] = 0;	inst[5] = 0;
-	inst[6] = 0;	inst[7] = 0;
-	memmove( inst, key, len);
+	inst[0] = 0;
+	inst[1] = 0;
+	inst[2] = 0;
+	inst[3] = 0;
+	inst[4] = 0;
+	inst[5] = 0;
+	inst[6] = 0;
+	inst[7] = 0;
+	memmove(inst, key, len);
 #ifdef WORDS_BIGENDIAN
 	inst[0] = byteswap32(inst[0]);
 	inst[1] = byteswap32(inst[1]);
@@ -134,15 +138,15 @@ int _mcrypt_set_key (word32 *inst, word32* key, int len) {
 	inst[6] = byteswap32(inst[6]);
 	inst[7] = byteswap32(inst[7]);
 #endif
-return 0;
+	return 0;
 }
 
 void _mcrypt_kboxinit(void)
 {
 	int i;
 
-	if (init==0) { 
-		init=1;
+	if (init == 0) {
+		init = 1;
 		for (i = 0; i < 256; i++) {
 			k87[i] = k8[i >> 4] << 4 | k7[i & 15];
 			k65[i] = k6[i >> 4] << 4 | k5[i & 15];
@@ -188,8 +192,7 @@ static word32 f(word32 x)
  *
  * The keys are defined similarly, with bit 256 being the msb of key[7].
  */
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(word32 const key[8], word32 * in)
+WIN32DLL_DEFINE void _mcrypt_encrypt(word32 const key[8], word32 * in)
 {
 	register word32 n1, n2;	/* As named in the GOST */
 
@@ -260,8 +263,7 @@ void _mcrypt_encrypt(word32 const key[8], word32 * in)
  * You could define an expanded key, or just write the code twice,
  * as done here.
  */
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(word32 const key[8], word32 * in)
+WIN32DLL_DEFINE void _mcrypt_decrypt(word32 const key[8], word32 * in)
 {
 	register word32 n1, n2;	/* As named in the GOST */
 
@@ -319,71 +321,97 @@ void _mcrypt_decrypt(word32 const key[8], word32 * in)
 
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return 8*sizeof(word32);}
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return 8 * sizeof(word32);
+}
 
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(1*sizeof(int));
-        size[0]=32;
-        *len=1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 32;
+	*len = 1;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "GOST");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "GOST"); return x;}
 
 #define CIPHER "e498cf78cdf1d4a5"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = calloc(1, blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc( _mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
