@@ -12,7 +12,7 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: loki97.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: loki97.c,v 1.8 2001/05/17 18:44:59 nmav Exp $ */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
@@ -218,8 +218,8 @@ void f_fun(word32 res[2], const word32 in[2], const word32 key[2])
 
 /* 256 bit version only */
 WIN32DLL_DEFINE
-int _mcrypt_set_key(word32 * l_key, const word32 in_key[],
-			    const word32 key_len)
+    int _mcrypt_set_key(word32 * l_key, const word32 in_key[],
+			const word32 key_len)
 {
 	word32 i, k1[2], k2[2], k3[2], k4[2], del[2], tt[2], sk[2];
 
@@ -276,7 +276,7 @@ int _mcrypt_set_key(word32 * l_key, const word32 in_key[],
 		l_key[i + i + 1] = k1[1];
 	}
 
-return 0;
+	return 0;
 }
 
 #define r_fun(l,r,k)        \
@@ -284,8 +284,7 @@ return 0;
     f_fun((r),(l),(k) + 2); \
     add_eq((l), (k) + 4)
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(word32 * l_key, word32 * _blk)
+WIN32DLL_DEFINE void _mcrypt_encrypt(word32 * l_key, word32 * _blk)
 {
 	word32 blk[4];
 
@@ -336,8 +335,7 @@ void _mcrypt_encrypt(word32 * l_key, word32 * _blk)
     f_fun((r),(l),(k) + 2); \
     sub_eq((l),(k))
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(word32 * l_key, word32 * _blk)
+WIN32DLL_DEFINE void _mcrypt_decrypt(word32 * l_key, word32 * _blk)
 {
 	word32 xs, blk[4];
 
@@ -384,73 +382,99 @@ void _mcrypt_decrypt(word32 * l_key, word32 * _blk)
 }
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return 96*sizeof(word32);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 16; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	int* size=malloc(3*sizeof(int));
-        size[0]=16;
-        size[1]=24;
-        size[2]=32;
-        *len=3;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return 96 * sizeof(word32);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 16;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
+	return size;
+}
+
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "LOKI97");
+	return x;
 }
-                                        
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "LOKI97"); return x;}
 
 #define CIPHER "8cb28c958024bae27a94c698f96f12a9"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
+	
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
-
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
