@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rc2.c,v 1.7 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: rc2.c,v 1.8 2001/05/16 17:54:25 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -43,11 +43,10 @@
 \**********************************************************************/
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(word16 * xkey, const byte * key,
-			     unsigned int len)
+    int _mcrypt_set_key(word16 * xkey, const byte * key, unsigned int len)
 {
 	unsigned int j;
-	byte *xkey_p=(void*)xkey;
+	byte *xkey_p = (void *) xkey;
 	int i;
 
 	/* 256-entry permutation table, probably derived somehow from pi */
@@ -105,11 +104,10 @@ int _mcrypt_set_key(word16 * xkey, const byte * key,
 	/* Phase 3 - copy to xkey in little-endian order */
 	i = 63;
 	do {
-		xkey[i] =  xkey_p[2*i] +
-		          (xkey_p[2*i+1] << 8);
+		xkey[i] = xkey_p[2 * i] + (xkey_p[2 * i + 1] << 8);
 	} while (i--);
-	
-return 0;
+
+	return 0;
 }
 
 
@@ -117,8 +115,7 @@ return 0;
 * Encrypt an 8-byte block of plaintext using the given key.            *
 \**********************************************************************/
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
+WIN32DLL_DEFINE void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
 
@@ -174,8 +171,7 @@ void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
 * Decrypt an 8-byte block of ciphertext using the given key.           *
 \**********************************************************************/
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
+WIN32DLL_DEFINE void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
 
@@ -227,68 +223,95 @@ void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 #endif
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return 64*sizeof(word16);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 128; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	*len=0;
-        return NULL;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return 64 * sizeof(word16);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 128;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	*len = 0;
+	return NULL;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "RC2");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "RC2"); return x;}
 
 #define CIPHER "becbe4c8e6237a14"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
