@@ -19,7 +19,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rijndael-256.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: rijndael-256.c,v 1.9 2001/05/17 19:09:08 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -138,7 +138,7 @@ static word32 InvMixCol(word32 x)
 	return y;
 }
 
-byte ByteSub(byte x)
+static byte ByteSub(byte x)
 {
 	byte y = ptab[255 - ltab[x]];	/* multiplicative inverse */
 	x = y;
@@ -154,7 +154,7 @@ byte ByteSub(byte x)
 	return y;
 }
 
-void _mcrypt_rijndael_gentables(void)
+static void _mcrypt_rijndael_gentables(void)
 {				/* generate tables */
 	int i;
 	byte y, b[4];
@@ -204,13 +204,12 @@ void _mcrypt_rijndael_gentables(void)
 	}
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_set_key(RI * rinst, byte * key, int nk)
+WIN32DLL_DEFINE int _mcrypt_set_key(RI * rinst, byte * key, int nk)
 {				/* blocksize=32*nb bits. Key=32*nk bits */
 	/* currently nb,bk = 4, 6 or 8          */
 	/* key comes as 4*rinst->Nk bytes              */
 	/* Key Scheduler. Create expanded encryption key */
-	int nb = 8;		/* 128 block size */
+	int nb = 8;		/* 256 block size */
 	int i, j, k, m, N;
 	int C1, C2, C3;
 	word32 CipherKey[8];
@@ -302,7 +301,7 @@ int _mcrypt_set_key(RI * rinst, byte * key, int nk)
 	}
 	for (j = N - rinst->Nb; j < N; j++)
 		rinst->rkey[j - N + rinst->Nb] = rinst->fkey[j];
-return 0;
+	return 0;
 }
 
 
@@ -310,8 +309,7 @@ return 0;
  * Instead of just one ftable[], I could have 4, the other     *
  * 3 pre-rotated to save the ROTL8, ROTL16 and ROTL24 overhead */
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(RI * rinst, byte * buff)
+WIN32DLL_DEFINE void _mcrypt_encrypt(RI * rinst, byte * buff)
 {
 	int i, j, k, m;
 	word32 a[8], b[8], *x, *y, *t;
@@ -358,8 +356,7 @@ void _mcrypt_encrypt(RI * rinst, byte * buff)
 	return;
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(RI * rinst, byte * buff)
+WIN32DLL_DEFINE void _mcrypt_decrypt(RI * rinst, byte * buff)
 {
 	int i, j, k, m;
 	word32 a[8], b[8], *x, *y, *t;
@@ -406,37 +403,35 @@ void _mcrypt_decrypt(RI * rinst, byte * buff)
 }
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size()
+WIN32DLL_DEFINE int _mcrypt_get_size()
 {
 	return sizeof(RI);
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size()
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
 {
 	return 32;
 }
 
-WIN32DLL_DEFINE
-int _is_block_algorithm()
+WIN32DLL_DEFINE int _is_block_algorithm()
 {
 	return 1;
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32;}
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(3*sizeof(int));
-        size[0]=16;
-        size[1]=24;
-        size[2]=32;
-        *len=3;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
 }
-WIN32DLL_DEFINE
-char *_mcrypt_get_algorithms_name()
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 {
 	char *x;
 	x = malloc(14);
@@ -446,29 +441,36 @@ char *_mcrypt_get_algorithms_name()
 
 #define CIPHER "45af6c269326fd935edd24733cff74fc1aa358841a6cd80b79f242d983f8ff2e"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test()
+WIN32DLL_DEFINE int _mcrypt_self_test()
 {
 	char *keyword;
-	unsigned char *plaintext;
-	unsigned char *ciphertext;
+	unsigned char plaintext[32];
+	unsigned char ciphertext[32];
 	int blocksize = _mcrypt_get_block_size(), j;
 	void *key;
 	unsigned char cipher_tmp[200];
 
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-	plaintext = malloc(blocksize);
+
 	for (j = 0; j < blocksize; j++) {
 		plaintext[j] = j % 256;
 	}
 	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
 	memcpy(ciphertext, plaintext, blocksize);
 
 	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
+
 	_mcrypt_encrypt(key, (void *) ciphertext);
 
 	for (j = 0; j < blocksize; j++) {
@@ -480,18 +482,21 @@ int _mcrypt_self_test()
 		printf("failed compatibility\n");
 		printf("Expected: %s\nGot: %s\n", CIPHER,
 		       (char *) cipher_tmp);
+		free(key);
 		return -1;
 	}
 	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
 
 	if (strcmp(ciphertext, plaintext) != 0) {
 		printf("failed internally\n");
 		return -1;
 	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
