@@ -21,7 +21,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: safer64.c,v 1.4 2001/01/22 22:13:19 nmav Exp $ */
+/* $Id: safer64.c,v 1.6 2001/05/17 19:09:08 nmav Exp $ */
 
 /******************* External Headers *****************************************/
 
@@ -47,20 +47,20 @@
 
 /******************* Constants ************************************************/
 #define TAB_LEN      256
-static int _safer_init=0;
+static int _safer64_init = 0;
 /******************* Assertions ***********************************************/
 
 /******************* Macros ***************************************************/
 #define ROL(x, n)    ((unsigned char)((unsigned int)(x) << (n)\
                                      |(unsigned int)((x) & 0xFF) >> (8 - (n))))
-#define EXP(x)       exp_tab[(x) & 0xFF]
-#define LOG(x)       log_tab[(x) & 0xFF]
+#define EXP(x)       exp_tab64[(x) & 0xFF]
+#define LOG(x)       log_tab64[(x) & 0xFF]
 #define PHT(x, y)    { y += x; x += y; }
 #define IPHT(x, y)   { x -= y; y -= x; }
 
 /******************* Types ****************************************************/
-static unsigned char exp_tab[TAB_LEN];
-static unsigned char log_tab[TAB_LEN];
+static unsigned char exp_tab64[TAB_LEN];
+static unsigned char log_tab64[TAB_LEN];
 
 /******************* Module Data **********************************************/
 
@@ -68,14 +68,14 @@ static unsigned char log_tab[TAB_LEN];
 
 /******************************************************************************/
 
-void _mcrypt_Safer_Init_Module(void)
+static void _mcrypt_Safer_Init_Module(void)
 {
 	unsigned int i, exp;
 
 	exp = 1;
 	for (i = 0; i < TAB_LEN; i++) {
-		exp_tab[i] = (unsigned char) (exp & 0xFF);
-		log_tab[exp_tab[i]] = (unsigned char) i;
+		exp_tab64[i] = (unsigned char) (exp & 0xFF);
+		log_tab64[exp_tab64[i]] = (unsigned char) i;
 		exp = exp * 45 % 257;
 	}
 }				/* Safer_Init_Module */
@@ -83,17 +83,18 @@ void _mcrypt_Safer_Init_Module(void)
 /******************************************************************************/
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
+    int _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey,
+			int len)
 {
 	unsigned int i, j;
 	unsigned char ka[SAFER_BLOCK_LEN + 1];
 	unsigned char kb[SAFER_BLOCK_LEN + 1];
 	int nof_rounds = SAFER_SK64_DEFAULT_NOF_ROUNDS;
 	int strengthened = 1;
-	
-	if (_safer_init==0) {
+
+	if (_safer64_init == 0) {
 		_mcrypt_Safer_Init_Module();
-		_safer_init=1;
+		_safer64_init = 1;
 	}
 	if (SAFER_MAX_NOF_ROUNDS < nof_rounds)
 		nof_rounds = SAFER_MAX_NOF_ROUNDS;
@@ -115,12 +116,12 @@ int _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
 				    (ka
 				     [(j + 2 * i - 1) %
 				      (SAFER_BLOCK_LEN + 1)] +
-				     exp_tab[exp_tab[18 * i + j + 1]]) &
+				     exp_tab64[exp_tab64[18 * i + j + 1]]) &
 				    0xFF;
 			else
 				*key++ =
 				    (ka[j] +
-				     exp_tab[exp_tab[18 * i + j + 1]]) &
+				     exp_tab64[exp_tab64[18 * i + j + 1]]) &
 				    0xFF;
 		for (j = 0; j < SAFER_BLOCK_LEN; j++)
 			if (strengthened)
@@ -128,24 +129,24 @@ int _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
 				    (kb
 				     [(j + 2 * i) %
 				      (SAFER_BLOCK_LEN + 1)] +
-				     exp_tab[exp_tab[18 * i + j + 10]]) &
+				     exp_tab64[exp_tab64[18 * i + j + 10]]) &
 				    0xFF;
 			else
 				*key++ =
 				    (kb[j] +
-				     exp_tab[exp_tab[18 * i + j + 10]]) &
+				     exp_tab64[exp_tab64[18 * i + j + 10]]) &
 				    0xFF;
 	}
 	for (j = 0; j < SAFER_BLOCK_LEN + 1; j++)
 		ka[j] = kb[j] = 0;
-return 0;
+	return 0;
 }				/* Safer_Expand_Userkey */
 
 /******************************************************************************/
 
 
 WIN32DLL_DEFINE
-void _mcrypt_encrypt( const safer_key_t * key, safer_block_t * block_in)
+    void _mcrypt_encrypt(const safer_key_t * key, safer_block_t * block_in)
 {
 	unsigned char a, b, c, d, e, f, g, h, t;
 	unsigned int round;
@@ -219,7 +220,7 @@ void _mcrypt_encrypt( const safer_key_t * key, safer_block_t * block_in)
 /******************************************************************************/
 
 WIN32DLL_DEFINE
-void _mcrypt_decrypt(const safer_key_t * key, safer_block_t * block_in)
+    void _mcrypt_decrypt(const safer_key_t * key, safer_block_t * block_in)
 {
 	safer_block_t a, b, c, d, e, f, g, h, t;
 	unsigned int round;
@@ -293,70 +294,95 @@ void _mcrypt_decrypt(const safer_key_t * key, safer_block_t * block_in)
 /******************************************************************************/
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return (1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 8; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int* size=malloc(1*sizeof(int));
-        size[0]=8;
-        *len=1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return (1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 8;
+	*len = 1;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "SAFER-SK64");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "SAFER-SK64"); return x;}
 
 #define CIPHER "e490eebffd908f34"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
+	}
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
 	}
-	key=malloc(_mcrypt_get_size());
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
