@@ -12,7 +12,7 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: saferplus.c,v 1.5 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: saferplus.c,v 1.6 2001/05/16 17:54:25 nmav Exp $ */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
@@ -190,8 +190,8 @@ byte safer_logf[512] = {
 /* word32  k_bytes; */
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(SPI * sp_key, const word32 * in_key,
-			       const word32 key_len)
+    int _mcrypt_set_key(SPI * sp_key, const word32 * in_key,
+			const word32 key_len)
 {
 	byte by, lk[33];
 	word32 i, j, k, l, m, *lkp = (void *) lk;
@@ -467,8 +467,7 @@ void do_ir(byte x[16], byte * kp)
 	x[15] = safer_logf[x[15] - kp[31] + 256] ^ kp[15];
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(SPI * spi, word32 * _blk)
+WIN32DLL_DEFINE void _mcrypt_encrypt(SPI * spi, word32 * _blk)
 {
 	byte *kp;
 	word32 __blk[16];
@@ -529,8 +528,7 @@ void _mcrypt_encrypt(SPI * spi, word32 * _blk)
 
 
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(SPI * spi, word32 * _blk)
+WIN32DLL_DEFINE void _mcrypt_decrypt(SPI * spi, word32 * _blk)
 {
 	byte *kp;
 	word32 __blk[16];
@@ -591,72 +589,96 @@ void _mcrypt_decrypt(SPI * spi, word32 * _blk)
 
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(SPI);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 16; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(3*sizeof(int));
-        size[0]=16;
-        size[1]=24;
-        size[2]=32;
-        *len=3;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(SPI);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 16;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "Safer+");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Safer+"); return x;}
 
 #define CIPHER "97fa76704bf6b578549f65c6f75b228b"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
