@@ -459,8 +459,8 @@ Mean:          941 cycles =    27.2 mbits/sec
 /* initialise the key schedule from the user supplied key   */
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
-			     word32 key_len)
+    int _mcrypt_set_key(SERPENT_KEY * spkey, const word32 * in_key,
+			word32 key_len)
 {
 	word32 i, lk, a, b, c, d, e, f, g, h;
 	word32 t1, t2, t3, t4, t5, t6, t7, t8, t9, t10, t11, t12, t13, t14,
@@ -477,7 +477,7 @@ int _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 	while (i < lk) {
 #ifdef WORDS_BIGENDIAN
 		spkey->l_key[i] = byteswap32(in_key[i]);
-#else 
+#else
 		spkey->l_key[i] = (in_key[i]);
 #endif
 		i++;
@@ -494,10 +494,9 @@ int _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 	}
 
 	for (i = 0; i < 132; ++i) {
-		lk =
-		    spkey->l_key[i] ^ spkey->l_key[i +
-						   3] ^ spkey->l_key[i +
-								     5] ^
+		lk = spkey->l_key[i] ^ spkey->l_key[i +
+						    3] ^ spkey->l_key[i +
+								      5] ^
 		    spkey->l_key[i + 7] ^ 0x9e3779b9 ^ i;
 
 		spkey->l_key[i + 8] = (lk << 11) | (lk >> 21);
@@ -608,8 +607,7 @@ int _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 
 /* encrypt a block of text  */
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(SERPENT_KEY * spkey, word32* in_blk)
+WIN32DLL_DEFINE void _mcrypt_encrypt(SERPENT_KEY * spkey, word32 * in_blk)
 {
 	word32 a, b, c, d, e, f, g, h;
 	word32 t1, t2, t3, t4, t5, t6, t7, t8, t9, t10, t11, t12, t13, t14,
@@ -739,8 +737,7 @@ void _mcrypt_encrypt(SERPENT_KEY * spkey, word32* in_blk)
 
 /* decrypt a block of text  */
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(SERPENT_KEY * spkey, word32 *in_blk)
+WIN32DLL_DEFINE void _mcrypt_decrypt(SERPENT_KEY * spkey, word32 * in_blk)
 {
 	word32 a, b, c, d, e, f, g, h;
 	word32 t1, t2, t3, t4, t5, t6, t7, t8, t9, t10, t11, t12, t13, t14,
@@ -869,73 +866,98 @@ void _mcrypt_decrypt(SERPENT_KEY * spkey, word32 *in_blk)
 }
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(SERPENT_KEY);}
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(SERPENT_KEY);
+}
 
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 16; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) { 
-	int* size=malloc(3*sizeof(int));
-	size[0]=16;
-	size[1]=24;
-	size[2]=32;
-	*len=3;
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 16;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
 	return size;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Serpent"); return x;}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "Serpent");
+	return x;
+}
 
 #define CIPHER "9a99455df5080bfccadf049b5aaf7d61"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
