@@ -15,8 +15,8 @@
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
  */
- 
-/* $Id: tripledes.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
+
+/* $Id: tripledes.c,v 1.7 2001/05/17 19:09:08 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -195,14 +195,14 @@ static int nibblebit[] = {
 /* Allocate space and initialize DES lookup arrays
  * mode == 0: standard Data Encryption Algorithm
  */
-int _mcrypt_desinit(TRIPLEDES_KEY* key)
+static int _mcrypt_desinit(TRIPLEDES_KEY * key)
 {
 
-	spinit( key, 0);
-	spinit( key, 1);
-	spinit( key, 2);
-	perminit( &key->iperm, ip);
-	perminit( &key->fperm, fp);
+	spinit(key, 0);
+	spinit(key, 1);
+	spinit(key, 2);
+	perminit(&key->iperm, ip);
+	perminit(&key->fperm, fp);
 
 
 	return 0;
@@ -211,7 +211,7 @@ int _mcrypt_desinit(TRIPLEDES_KEY* key)
 
 /* Set key (initialize key schedule array) */
 WIN32DLL_DEFINE
-int _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
+    int _mcrypt_set_key(TRIPLEDES_KEY * dkey, char *user_key, int len)
 {
 	char pc1m[56];		/* place to modify pc1 into */
 	char pcr[56];		/* place to rotate pc1 into */
@@ -222,11 +222,11 @@ int _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
 	char *user_key3 = &user_key[16];
 
 	_mcrypt_desinit(dkey);
-	
+
 	/* Clear key schedule */
-	Bzero( dkey->kn[0], 16 * 8);
-	Bzero( dkey->kn[1], 16 * 8);
-	Bzero( dkey->kn[2], 16 * 8);
+	Bzero(dkey->kn[0], 16 * 8);
+	Bzero(dkey->kn[1], 16 * 8);
+	Bzero(dkey->kn[2], 16 * 8);
 
 	/* DES 1 */
 	for (j = 0; j < 56; j++) {	/* convert pc1 to bits of key */
@@ -300,7 +300,7 @@ int _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
 			}
 		}
 	}
-return 0;
+	return 0;
 }
 
 
@@ -308,8 +308,7 @@ return 0;
 
 /* In-place encryption of 64-bit block */
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(TRIPLEDES_KEY *key, char* block)
+WIN32DLL_DEFINE void _mcrypt_encrypt(TRIPLEDES_KEY * key, char *block)
 {
 	register word32 left, right;
 	register char *knp;
@@ -331,37 +330,37 @@ void _mcrypt_encrypt(TRIPLEDES_KEY *key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[0][0][0];
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp += 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp += 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 
 /* DES 2 */
 
@@ -371,37 +370,37 @@ void _mcrypt_encrypt(TRIPLEDES_KEY *key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[1][15][0];
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp -= 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp -= 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 
 	/* Do the 16 rounds.
 	 * The rounds are numbered from 0 to 15. On even rounds
@@ -409,37 +408,37 @@ void _mcrypt_encrypt(TRIPLEDES_KEY *key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[2][0][0];
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp += 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp += 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 
 	/* Left/right half swap, plus byte swap if little-endian */
 #ifndef	WORDS_BIGENDIAN
@@ -452,12 +451,12 @@ void _mcrypt_encrypt(TRIPLEDES_KEY *key, char* block)
 	permute((char *) work, key->fperm, block);	/* Inverse initial permutation */
 
 }
+
 /* In-place decryption of 64-bit block. This function is the mirror
  * image of encryption; exactly the same steps are taken, but in
  * reverse order
  */
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(TRIPLEDES_KEY* key, char* block)
+WIN32DLL_DEFINE void _mcrypt_decrypt(TRIPLEDES_KEY * key, char *block)
 {
 	register word32 left, right;
 	register char *knp;
@@ -482,37 +481,37 @@ void _mcrypt_decrypt(TRIPLEDES_KEY* key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[2][15][0];
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 	knp -= 8;
-	right ^= f( key, 2, left, knp);
+	right ^= f(key, 2, left, knp);
 	knp -= 8;
-	left ^= f( key, 2, right, knp);
+	left ^= f(key, 2, right, knp);
 
 
 /* DES 2*/
@@ -522,37 +521,37 @@ void _mcrypt_decrypt(TRIPLEDES_KEY* key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[1][0][0];
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 	knp += 8;
-	left ^= f( key, 1, right, knp);
+	left ^= f(key, 1, right, knp);
 	knp += 8;
-	right ^= f( key, 1, left, knp);
+	right ^= f(key, 1, left, knp);
 
 /* DES 1 */
 	/* Do the 16 rounds in reverse order.
@@ -561,37 +560,37 @@ void _mcrypt_decrypt(TRIPLEDES_KEY* key, char* block)
 	 * the left half; on odd rounds the reverse is done.
 	 */
 	knp = &key->kn[0][15][0];
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 	knp -= 8;
-	right ^= f( key, 0, left, knp);
+	right ^= f(key, 0, left, knp);
 	knp -= 8;
-	left ^= f( key, 0, right, knp);
+	left ^= f(key, 0, right, knp);
 
 
 #ifndef	WORDS_BIGENDIAN
@@ -605,7 +604,7 @@ void _mcrypt_decrypt(TRIPLEDES_KEY* key, char* block)
 }
 
 /* Permute inblock with perm */
-static void permute( char* inblock, char perm[16][16][8], char *outblock)
+static void permute(char *inblock, char perm[16][16][8], char *outblock)
 {
 	register char *ib, *ob;	/* ptr to input or output block */
 	register char *p, *q;
@@ -637,7 +636,8 @@ static void permute( char* inblock, char perm[16][16][8], char *outblock)
 }
 
 /* The nonlinear function f(r,k), the heart of DES */
-static word32 f(TRIPLEDES_KEY* key, int pos, register word32 r, register char* subkey)
+static word32 f(TRIPLEDES_KEY * key, int pos, register word32 r,
+		register char *subkey)
 {
 	register word32 *spp;
 	register word32 rval, rt;
@@ -687,6 +687,7 @@ static word32 f(TRIPLEDES_KEY* key, int pos, register word32 r, register char* s
 #endif
 	return rval;
 }
+
 /* initialize a perm array */
 static void perminit(char perm[16][16][8], char p[64])
 {
@@ -710,7 +711,7 @@ static void perminit(char perm[16][16][8], char p[64])
 }
 
 /* Initialize the lookup table for the combined S and P boxes */
-static void spinit(TRIPLEDES_KEY* key, int pos)
+static void spinit(TRIPLEDES_KEY * key, int pos)
 {
 	char pbox[32];
 	int p, i, s, j, rowcol;
@@ -745,84 +746,109 @@ static void spinit(TRIPLEDES_KEY* key, int pos)
 			key->sp[pos][s][i] = val;
 
 #ifdef	DEBUG
-			printf("sp[%d][%2d] = %08lx\n", s, i, sp[pos][s][i]);
+			printf("sp[%d][%2d] = %08lx\n", s, i,
+			       sp[pos][s][i]);
 #endif
 		}
 	}
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(TRIPLEDES_KEY);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 24; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int* size=malloc(1*sizeof(int));
-        size[0]=24;
-        *len=1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(TRIPLEDES_KEY);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 24;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 24;
+	*len = 1;
+	return size;
+}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "3DES");
+	return x;
 }
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "3DES"); return x;}
 
 #define CIPHER "58ed248f77f6b19e"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=j%256;
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
-
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n%s\n", cipher_tmp);
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
+	}
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n%s\n", cipher_tmp);
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
