@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  * 
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -35,10 +35,10 @@
 #endif
 
 typedef struct cfb_buf {
-	word8* sd_register;
-	word8* s_register;
-	word8* enc_s_register;
-	word8* enc_sd_register;
+	byte* sd_register;
+	byte* s_register;
+	byte* enc_s_register;
+	byte* enc_sd_register;
 } CFB_BUFFER;
 
 /* CFB MODE */
@@ -50,8 +50,13 @@ int _init_mcrypt( CFB_BUFFER* buf, void *key, int lenofkey, void *IV, int size)
 	buf->s_register=malloc( size);
 	buf->enc_s_register=malloc( size);
 	buf->enc_sd_register=malloc( size);
-	memmove(buf->sd_register, IV, size);
-	memmove(buf->s_register, IV, size);
+	if (IV!=NULL) {
+		memmove(buf->sd_register, IV, size);
+		memmove(buf->s_register, IV, size);
+	} else {
+		memset(buf->sd_register, 0, size);
+		memset(buf->s_register, 0, size);	
+	}
 /* End cfb */
 	return 0;
 }
@@ -136,7 +141,6 @@ int _is_block_algorithm_mode() { return 1; }
 char *_mcrypt_get_modes_name() { char*x; x=malloc(10); strcpy(x, "CFB"); return x;}
 int _mcrypt_mode_get_size () {return sizeof(CFB_BUFFER);}
 
-
 word32 _mcrypt_mode_version() {
-	return 20000331;
+	return 20010201;
 }
