@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  * 
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -42,7 +42,7 @@ int _mcrypt_set_state( void* buf, void *IV, int size) { return -1; }
 
 int _end_mcrypt(void* ign) {return 0;}
 
-int _mcrypt( void* ign, void *plaintext, int len, int blocksize, void* akey, void (*func)(void*,void*, int))
+int _mcrypt( void* ign, void *plaintext, int len, int blocksize, void* akey, void (*func)(void*,void*, int), void (*func2)(void*,void*, int))
 {
 	void (*_mcrypt_stream_encrypt) (void *, void *, int);
 
@@ -54,11 +54,11 @@ int _mcrypt( void* ign, void *plaintext, int len, int blocksize, void* akey, voi
 
 
 
-int _mdecrypt( void* ign, void *ciphertext, int len, int blocksize, void* akey, void (*func)(void*,void*, int))
+int _mdecrypt( void* ign, void *ciphertext, int len, int blocksize, void* akey, void (*func)(void*,void*, int), void (*func2)(void*,void*, int))
 {
 	void (*_mcrypt_stream_decrypt) (void *, void *, int);
 
-	_mcrypt_stream_decrypt = func;
+	_mcrypt_stream_decrypt = func2;
 
 	_mcrypt_stream_decrypt(akey, ciphertext, len);
 	return 0;
