@@ -34,7 +34,7 @@ int main()
 {
 	MCRYPT td, td2;
 	int i, t, imax;
-	int j, jmax;
+	int j, jmax, ivsize;
 	int x = 0, siz;
 	char **names;
 	char **modes;
@@ -64,11 +64,17 @@ int main()
 					key = calloc(1, keysize);
 					for (t=0;t<keysize;t++)
 						key[t] = (t % 255) + 13;
-					IV = calloc( 1, mcrypt_enc_get_iv_size(td));
-					for (t=0;t<mcrypt_enc_get_iv_size(td);t++)
-						IV[t] = (t*2 % 255) + 15;
-						
-					mcrypt_generic_init( td, key, keysize, IV);
+					
+					ivsize = mcrypt_enc_get_iv_size(td);
+					if (ivsize>0) {
+						IV = calloc( 1, ivsize);
+						for (t=0;t<ivsize;t++)
+							IV[t] = (t*2 % 255) + 15;
+					}
+					if (mcrypt_generic_init( td, key, keysize, IV) < 0) {
+						fprintf(stderr, "Failed to Initialize algorithm!\n");
+						return -1;
+					}
 
 					siz = (strlen(TEXT) / mcrypt_enc_get_block_size(td))*mcrypt_enc_get_block_size(td);
 					text = calloc( 1, siz);
@@ -76,7 +82,11 @@ int main()
 
 					mcrypt_generic( td, text, siz);
 
-					mcrypt_generic_init( td2, key, keysize, IV);
+					if (mcrypt_generic_init( td2, key, keysize, IV) < 0) {
+						fprintf(stderr, "Failed to Initialize algorithm!\n");
+						return -1;
+					}
+
 					mdecrypt_generic( td2, text, siz);
 					if ( memcmp( text, TEXT, siz) == 0) {
 						printf( "   %s: ok\n", modes[i]);
@@ -84,18 +94,22 @@ int main()
 						printf( "   %s: failed\n", modes[i]);
 						x=1;
 					}
-					mcrypt_generic_end(td);
-					mcrypt_generic_end(td2);
-					free(text);
+					mcrypt_generic_deinit(td);
+					mcrypt_generic_deinit(td2);
+					mcrypt_module_close(td);
+					mcrypt_module_close(td2);					free(text);
 					free(key);
-					free(IV);
+					if (ivsize>0) free(IV);
 				}
 			}
 		printf("\n");
 		
 	}	
+	mcrypt_free_p(names, jmax);
+	mcrypt_free_p(modes, imax);
+	
 
 	if (x>0) fprintf(stderr, "\nProbably some of the algorithms listed above failed. "
-				"Try not to use these algorithms, and file a bug report to mcrypt-dev@argeas.cs-net.gr\n\n");
+				"Try not to use these algorithms, and file a bug report to mcrypt-dev@lists.hellug.gr\n\n");
 	return x;
 }
